# New Ticket Created by  Simon Glover 
# Please include the string:  [perl #15731]
# in the subject line of all future correspondence about this issue. 
# <URL: http://rt.perl.org/rt2/Ticket/Display.html?id=15731 >



 Patch below kills a couple of warnings that cropped up because
 alloc_more_objects was renamed to alloc_objects in the code but
 not the headers. Also updates the comments.

 Simon


--- include/parrot/smallobject.h.old    Sun Jul 28 17:36:30 2002
+++ include/parrot/smallobject.h        Sun Jul 28 17:44:37 2002
@@ -30,9 +30,9 @@ struct Small_Object_Pool {
     /* allocates more objects */
     void  (*alloc_objects)(struct Parrot_Interp *,
                            struct Small_Object_Pool *);
     /* makes more objects available. can call alloc_more_objects */
     void  (*more_objects)(struct Parrot_Interp *,
-                              struct Small_Object_Pool *);
+                          struct Small_Object_Pool *);
     void *mem_pool;
     size_t start_arena_memory;
     size_t end_arena_memory;
@@ -55,8 +55,9 @@ void add_free_object(struct Parrot_Inter
                      struct Small_Object_Pool *, void *);
 void *get_free_object(struct Parrot_Interp *,
                       struct Small_Object_Pool *);
-void alloc_more_objects(struct Parrot_Interp *,
-                        struct Small_Object_Pool *);
+
+void alloc_objects(struct Parrot_Interp *, struct Small_Object_Pool *);
+
 struct Small_Object_Pool * new_small_object_pool(struct Parrot_Interp *,
                                                  size_t, size_t);
@@ -30,9 +30,9 @@ struct Small_Object_Pool {
     void  (*alloc_objects)(struct Parrot_Interp *,
                            struct Small_Object_Pool *);
-    /* makes more objects available. can call alloc_more_objects */
+    /* makes more objects available. can call alloc_objects */
     void  (*more_objects)(struct Parrot_Interp *,




Reply via email to